#
# Pie and Bar Chart Example
#

from random import randint
from math import sin, cos

# This function returns a color with random red, green, and blue components.
#
def makeRandomColor():
  r = randint(0, 255)
  g = randint(0, 255)
  b = randint(0, 255)
  return makeColor(r, g, b)


# This function takes a list of integers and the desired size of the chart
# (this value serves as both the width and height), and returns a picture
# containing a pie chart drawn from the list. Each slice of the pie is
# drawn with a random color.
#
# An interesting extension of this for students would be to have them keep
# a fixed list of colors (for example, [red, green, blue, yellow, ...])
# and walk through those one by one to color slice after slice. How would
# they handle the situation where they have more slices than colors in the
# list -- wrap around, wrap around and lighten/darken, or something else?
#
def makePieChart(data, size):
  picture = makeEmptyPicture(size, size)
  
  total = sum(data)
  startAngle = 0
  
  for value in data:
    fraction = float(value) / total
    sliceAngle = int(round(fraction * 360))
    
    sliceColor = makeRandomColor()
    
    addArcFilled(picture, 0, 0, size, size, startAngle, sliceAngle, sliceColor)
    startAngle = startAngle + sliceAngle

  return picture


# This function takes a list of integers and the desired width and height of
# the chart (this time as separate values), and returns a picture containing
# a bar chart drawn from the list. Each bar is drawn with a random color.
#
# The same color-based extension could be used here, but a bar chart offers
# even more possibilities. This version simply draws all the bars without any
# margin around the edges or padding between the bars. Inserting padding
# between the bars is a trivial change. What about drawing horizontal and
# vertical axes? Ambitious students might want to try adding tick marks,
# grid lines, and even text labels.
#
def makeBarChart(data, width, height):
  picture = makeEmptyPicture(width, height)
  
  largest = max(data)
  barWidth = width / len(data)
  barStart = 0
  
  for value in data:
    fraction = float(value) / largest
    barHeight = int(round(fraction * height))
    
    barColor = makeRandomColor()
    
    addRectFilled(picture, barStart, height - barHeight, barWidth, barHeight, barColor)
    barStart = barStart + barWidth

  return picture


# This function provides an input loop that asks the user for numbers to add
# to a list until the enter the number 0.
#
def askForData():
  data = []
  prompt = 'Enter a value, or 0 to stop: '

  value = int(input(prompt))
  while value != 0:
    data.append(value)
    value = int(input(prompt))
    
  return data


# We can create a list with fixed data to graph...
#data = [73, 18, 29, 50]

# ... or we can have the user enter it themselves.
data = askForData()

# Draw and show the pie chart.
pie = makePieChart(data, 300)
show(pie)

# Draw and show the bar chart.
bar = makeBarChart(data, 300, 200)
show(bar)
